@@ -58,6 +58,10 @@ class BaseModel(object):
 
     @classmethod
     def _constructor_init(cls, target, kwargs={}) -> None:
+        cls._from_query_init(target)
+
+    @classmethod
+    def _from_query_init(cls, target):
         target._session = inspect(target).session
         target._action = None
 
@@ -117,6 +121,14 @@ class BaseModel(object):
         # setattr(new_session, "_conn_name", conn_name)
         return new_session
 
+    def load_action(self) -> None:
+        """Load action."""
+
+        self._action = application.PROJECT.actions[self.__tablename__]
+        if self._action is not None:
+            if self._action._record_script and not self._action._record_widget:
+                self._action.load_record_widget()
+
     def _common_init(self) -> None:
         """Initialize."""
         self.bufferChanged = dummy_signal.FakeSignal(self)  # pylint: disable=invalid-name
@@ -124,10 +136,14 @@ class BaseModel(object):
         self._cached_bufferchanged = {}
 
         if self.__tablename__ in application.PROJECT.actions.keys():
-            self._action = application.PROJECT.actions[self.__tablename__]
-            if self._action is not None:
-                if self._action._record_script and not self._action._record_widget:
-                    self._action.load_record_widget()
+            self.load_action()
+
+        # else:
+        #    self._error_manager(
+        #        "_common_init",
+        #        "%s no se encuentra en %s"
+        #        % (self.__tablename__, application.PROJECT.actions.keys()),
+        #    )
 
         self._deny_buffer_changed = []
 
@@ -340,31 +356,60 @@ class BaseModel(object):
                                             "obj: %s, pk_value: %s can't deleted" % (obj, obj.pk),
                                         )
 
-    def _flush(self) -> None:
+    def _flush(
+        self, relations: List[str] = [], only: List[str] = [], ignore_foreignkey: bool = False
+    ) -> None:
         """Flush data."""
 
         if self._session is None:
             self._error_manager("_flush", "_session is empty")
         else:
+
             self._current_mode = self.mode_access
-            self._before_flush()
+            if not only or "before_flush" in only:
+                self._before_flush()
 
-            self._check_integrity()
+            if not only or "check_integrity" in only:
+                self._check_integrity(ignore_foreignkey=ignore_foreignkey)
 
-            if self._current_mode == 2:  # delete
-                self._delete_cascade()
+            if not only or "delete_cascade" in only:
+                if self._current_mode == 2:  # delete
+                    self._delete_cascade()
 
-                if (
-                    self not in self._session.deleted
-                ):  # hay que hacerlo aquí, despues de before_* , porque si nó, cualquier session.flush borraria el padre.
-                    self._session.delete(self)
+                    if (
+                        self not in self._session.deleted
+                    ):  # hay que hacerlo aquí, despues de before_* , porque si nó, cualquier session.flush borraria el padre.
+                        self._session.delete(self)
 
-            try:
-                do_flush(self._session, self)
-            except Exception as error:
-                self._error_manager("_flush", error)
+            if not only or "flush" in only:
+                for relation in relations:
+                    list_objects = getattr(self, relation, [])
 
-            self._after_flush()
+                    for list_object in list_objects:
+                        list_object._flush(
+                            only=["before_flush", "check_integrity", "delete_cascade"],
+                            ignore_foreignkey=True,
+                        )
+                try:
+
+                    flush_objects = [self]
+                    for relation in relations:
+                        list_objects = getattr(self, relation, [])
+                        for list_object in list_objects:
+                            flush_objects.append(list_object)
+
+                    do_flush(self._session, flush_objects)
+
+                except Exception as error:
+                    self._error_manager("_flush", error)
+
+                for relation in relations:
+                    list_objects = getattr(self, relation, [])
+                    for list_object in list_objects:
+                        list_object._flush(only=["after_flush"])
+
+            if not only or "after_flush" in only:
+                self._after_flush()
             # else:
             #    self._current_mode = 3  # edit
         self._current_mode = None
@@ -374,13 +419,11 @@ class BaseModel(object):
 
         try:
             mode = self._current_mode
-
             func_ = getattr(self.module_iface, self._before_commit_function, None)
             if func_ is not None:
                 value = func_(self._cursor)
                 if value and not isinstance(value, bool) or value is False:
                     self._error_manager("beforeCommit", "%s return False" % func_)
-
         except Exception as error:
             self._error_manager("_before_flush", error)
 
@@ -559,7 +602,7 @@ class BaseModel(object):
 
             setattr(self, name, default_value)
 
-    def save(self) -> bool:
+    def save(self, relations: List[str] = []) -> bool:
         """Flush instance to current session."""
 
         if not hasattr(self, "_session"):
@@ -580,14 +623,14 @@ class BaseModel(object):
                 if self.mode_access == 0:  # insert
                     self._session.add(self)
 
-                self._flush()
+                self._flush(relations)
 
             self.update_copy()
 
             return True
         return False
 
-    def _check_integrity(self) -> bool:
+    def _check_integrity(self, ignore_foreignkey: bool = False) -> bool:
         """Check data integrity."""
 
         mode = self.mode_access
@@ -685,7 +728,11 @@ class BaseModel(object):
                             setattr(self, field_name, None)
                             value = None
 
-                        if qry_data is None and (not field.allowNull() or value):
+                        if (
+                            qry_data is None
+                            and (not field.allowNull() or value)
+                            and not ignore_foreignkey
+                        ):
 
                             self._error_manager(
                                 "_check_integrity",
@@ -918,10 +965,18 @@ class BaseModel(object):
 
     def get_module_iface(self) -> Optional[types.ModuleType]:
         """Return module iface."""
+        if not hasattr(
+            self, "_action"
+        ):  # Puede ocurrir por ejemplo en resultado de consulta de delete cascade
+            self._from_query_init(self)
+
         action = self._action
         if action is not None:
             module_action = None
-            if action._mod is not None and action._mod.module_name in application.PROJECT.actions:
+            if (
+                action._mod is not None
+                and action._mod.module_name in application.PROJECT.actions.keys()
+            ):
                 module_action = application.PROJECT.actions[action._mod.module_name]
 
                 if module_action is not None:
@@ -930,6 +985,7 @@ class BaseModel(object):
                         module_script = (
                             module_action.load_master_widget()  # type: ignore [unreachable] # noqa: F821
                         )
+
                     return getattr(module_script, "iface", module_script)
 
         return None
