@@ -251,7 +251,7 @@ def setup_gui(app: "QtWidgets.QApplication") -> None:
     app.setFont(font)
 
 
-def init_testing(level: int = 1000) -> None:
+def init_testing(file_name: str = "") -> None:
     """Initialize Pineboo for testing purposes."""
     settings.CONFIG.set_value("application/dbadmin_enabled", True)
 
@@ -268,21 +268,32 @@ def init_testing(level: int = 1000) -> None:
         init_cli(catch_ctrl_c=False)
 
         LOGGER.info("PINEBOO TESTING %s.", application.PINEBOO_VER)
-        # application.PROJECT.load_version()
-        application.PROJECT.setDebugLevel(level)
+
         application.PROJECT.set_app(qapp)
 
         dgi = dgi_module.load_dgi("qt", None)
 
         application.PROJECT.init_dgi(dgi)
 
-    setattr(application, "TESTING_MODE", True)
+    application.TESTING_MODE = True
     application.PROJECT.aq_app._inicializing = False
     conn = connection.connect_to_db(connection.IN_MEMORY_SQLITE_CONN)
 
     if not application.PROJECT.init_conn(connection=conn):
         raise Exception("No main connection was established. Aborting Pineboo load.")
 
+    # Si hay un dump para cargar se carga y así agilizamos inicialización de módulos!
+    if file_name:
+        file_path = os.path.join(application.PROJECT.tmpdir, "cache", file_name)
+        LOGGER.warning("Buscando fichero DUMP %s." % file_path)
+        if os.path.exists(file_path):
+            LOGGER.warning("Cargando DUMP.")
+            drv = application.PROJECT.conn_manager.default().driver()
+            db_api_con = drv.connection().connection
+            db_api_cursor = db_api_con.cursor()
+            with open(file_path, "r") as file_:
+                db_api_cursor.executescript(file_.read())
+
     # application.PROJECT.no_python_cache = False
     _initialize_data()
 
